# chercher-plugin-md

[Chercher](https://github.com/dnlzrgz/chercher) plugin that adds support for markdown files.

## Installation

> [!NOTE]
> This plugin is included with Chercher by default, so no additional installation is necessary

## Settings

> [!NOTE]
> This plugin does not requires any additional settings.
